
<template>
  <view-grid
    ref="grid"
    :columns="columns"
    :detail="detail"
    :editFormFields="editFormFields"
    :editFormOptions="editFormOptions"
    :searchFormFields="searchFormFields"
    :searchFormOptions="searchFormOptions"
    :table="table"
    :extend="extend"
  >
  </view-grid>
</template>
  <script>
import extend from "@/extension/quartzJob/dispatchInfo.js";
import { ref, defineComponent } from "vue";
export default defineComponent({
  setup() {
    const table = ref({
      key: "id",
      footer: "Foots",
      cnName: "调度服务配置信息",
      name: "dispatchInfo",
      url: "/DispatchInfo/",
      sortName: "createDate",
    });
    const editFormFields = ref({
      name: "",
      jobGroup: "",
      assemblyName: "",
      className: "",
      intervalSecond: "",
      beginTime: "",
      endTime: "",
      remark: "",
    });
    const editFormOptions = ref([
      [
        {
          title: "任务名称",
          required: true,
          field: "name",
          type: "string",
        },
        {
          title: "任务分组",
          required: true,
          field: "jobGroup",
          type: "select",
          dataKey: "deviceType",
          data: [],
        },
        {
          title: "程序集名称",
          required: true,
          field: "assemblyName",
          type: "string",
          type: "select",
          dataKey: "jobAssembly",
          data: [],
        },
        {
          title: "任务所在类",
          required: true,
          field: "className",
          type: "string",
          type: "select",
          dataKey: "jobClassName",
          data: [],
        },
      ],
      [
        {
          title: "间隔时间",
          required: true,
          field: "intervalSecond",
          type: "number",
        },
        {
          title: "开始时间",
          field: "beginTime",
          type: "datetime",
        },
        {
          title: "结束时间",
          field: "endTime",
          type: "datetime",
        },
        {
          title: "备注",
          field: "remark",
          type: "string",
        },
      ],
    ]);
    const searchFormFields = ref({
      name: "",
      jobGroup: "",
      assemblyName: "",
      className: "",
    });
    const searchFormOptions = ref([
      [
         {
          title: "任务名称",
          field: "name",
          type: "like",
        },
        {
          title: "任务分组",
          field: "jobGroup",
          type: "select",
          dataKey: "deviceType",
          data: [],
        },
        {
          title: "程序集名称",
          field: "assemblyName",
          type: "like",
        },
        {
          title: "任务所在类",
          field: "className",
          type: "like",
        },
      ],
    ]);
    const columns = ref([
      {
        field: "id",
        title: "Id",
        type: "int",
        width: 90,
        hidden: true,
        readonly: true,
        require: true,
        align: "left",
      },
      {
        field: "name",
        title: "任务名称",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "jobGroup",
        title: "任务分组",
        type: "string",
        width: 180,
        align: "left",
        bind: { key: "deviceType", data: [] },
      },
      {
        field: "assemblyName",
        title: "程序集名称",
        type: "string",
        width: 180,
        align: "left",
      },
      {
        field: "className",
        title: "任务所在类",
        type: "int",
        width: 200,
        align: "left",
      },
      {
        field: "intervalSecond",
        title: "执行间隔时间",
        type: "int",
        width: 120,
        align: "left",
      },
      {
        field: "beginTime",
        title: "开始时间",
        type: "datetime",
        width: 150,
        align: "left",
      },
      {
        field: "endTime",
        title: "结束时间",
        type: "int",
        width: 150,
        align: "left",
      },
      {
        field: "creater",
        title: "创建人",
        type: "string",
        width: 90,
        align: "left",
      },
      {
        field: "createDate",
        title: "创建时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "modifier",
        title: "修改人",
        type: "string",
        width: 100,
        align: "left",
      },
      {
        field: "modifyDate",
        title: "修改时间",
        type: "datetime",
        width: 160,
        align: "left",
      },
      {
        field: "remark",
        title: "备注",
        type: "string",
        width: 100,
        align: "left",
      },
    ]);
    const detail = ref({
      cnName: "",
      table: "",
      columns: [],
      sortName: "",
      key: "",
    });
    return {
      table,
      extend,
      editFormFields,
      editFormOptions,
      searchFormFields,
      searchFormOptions,
      columns,
      detail,
    };
  },
});
</script>
  